@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # This file is part of Glances.
 #
@@ -9,46 +8,39 @@
 
 """CPU percent stats shared between CPU and Quicklook plugins."""
 
+import psutil
+
 from glances.logger import logger
 from glances.timer import Timer
 
-import psutil
 
-
-class CpuPercent(object):
+class CpuPercent:
     """Get and store the CPU percent."""
 
-    def __init__(self, cached_timer_cpu=3):
-        self.cpu_info = {'cpu_name': None, 'cpu_hz_current': None, 'cpu_hz': None}
-        self.cpu_percent = 0
-        self.percpu_percent = []
-
-        # Get CPU name
-        self.__get_cpu_name()
-
+    def __init__(self, cached_timer_cpu=2):
         # cached_timer_cpu is the minimum time interval between stats updates
         # since last update is passed (will retrieve old cached info instead)
         self.cached_timer_cpu = cached_timer_cpu
-        self.timer_cpu = Timer(0)
-        self.timer_percpu = Timer(0)
-
         # psutil.cpu_freq() consumes lots of CPU
-        # So refresh the stats every refresh*2 (6 seconds)
+        # So refresh CPU frequency stats every refresh * 2
         self.cached_timer_cpu_info = cached_timer_cpu * 2
+
+        # Get CPU name
         self.timer_cpu_info = Timer(0)
+        self.cpu_info = {'cpu_name': self.__get_cpu_name(), 'cpu_hz_current': None, 'cpu_hz': None}
+
+        # Warning from PsUtil documentation
+        # The first time this function is called with interval = 0.0 or None
+        # it will return a meaningless 0.0 value which you are supposed to ignore.
+        self.timer_cpu = Timer(0)
+        self.cpu_percent = self.get_cpu()
+        self.timer_percpu = Timer(0)
+        self.percpu_percent = self.get_percpu()
 
     def get_key(self):
         """Return the key of the per CPU list."""
         return 'cpu_number'
 
-    def get(self, percpu=False):
-        """Update and/or return the CPU using the psutil library.
-        If percpu, return the percpu stats"""
-        if percpu:
-            return self.__get_percpu()
-        else:
-            return self.__get_cpu()
-
     def get_info(self):
         """Get additional information about the CPU"""
         # Never update more than 1 time per cached_timer_cpu_info
@@ -57,7 +49,7 @@ class CpuPercent(object):
             try:
                 cpu_freq = psutil.cpu_freq()
             except Exception as e:
-                logger.debug('Can not grab CPU information ({})'.format(e))
+                logger.debug(f'Can not grab CPU information ({e})')
             else:
                 if hasattr(cpu_freq, 'current'):
                     self.cpu_info['cpu_hz_current'] = cpu_freq.current
@@ -73,28 +65,39 @@ class CpuPercent(object):
 
     def __get_cpu_name(self):
         # Get the CPU name once from the /proc/cpuinfo file
-        # TODO: Multisystem...
+        # Read the first line with the "model name" ("Model" for Raspberry Pi)
+        ret = None
         try:
-            self.cpu_info['cpu_name'] = open('/proc/cpuinfo', 'r').readlines()[4].split(':')[1].strip()
-        except (FileNotFoundError, PermissionError, IndexError, KeyError, AttributeError):
-            self.cpu_info['cpu_name'] = 'CPU'
-        return self.cpu_info['cpu_name']
+            cpuinfo_file = open('/proc/cpuinfo').readlines()
+        except (FileNotFoundError, PermissionError):
+            pass
+        else:
+            for line in cpuinfo_file:
+                if line.startswith('model name') or line.startswith('Model') or line.startswith('cpu model'):
+                    ret = line.split(':')[1].strip()
+                    break
+        return ret if ret else 'CPU'
 
-    def __get_cpu(self):
+    def get_cpu(self):
         """Update and/or return the CPU using the psutil library."""
         # Never update more than 1 time per cached_timer_cpu
         if self.timer_cpu.finished():
-            self.cpu_percent = psutil.cpu_percent(interval=0.0)
             # Reset timer for cache
             self.timer_cpu.reset(duration=self.cached_timer_cpu)
+            # Update the stats
+            self.cpu_percent = psutil.cpu_percent(interval=0.0)
         return self.cpu_percent
 
-    def __get_percpu(self):
+    def get_percpu(self):
         """Update and/or return the per CPU list using the psutil library."""
         # Never update more than 1 time per cached_timer_cpu
         if self.timer_percpu.finished():
-            self.percpu_percent = []
-            for cpu_number, cputimes in enumerate(psutil.cpu_times_percent(interval=0.0, percpu=True)):
+            # Reset timer for cache
+            self.timer_percpu.reset(duration=self.cached_timer_cpu)
+            # Get stats
+            percpu_percent = []
+            psutil_percpu = enumerate(psutil.cpu_times_percent(interval=0.0, percpu=True))
+            for cpu_number, cputimes in psutil_percpu:
                 cpu = {
                     'key': self.get_key(),
                     'cpu_number': cpu_number,
@@ -119,9 +122,9 @@ class CpuPercent(object):
                 if hasattr(cputimes, 'guest_nice'):
                     cpu['guest_nice'] = cputimes.guest_nice
                 # Append new CPU to the list
-                self.percpu_percent.append(cpu)
-                # Reset timer for cache
-                self.timer_percpu.reset(duration=self.cached_timer_cpu)
+                percpu_percent.append(cpu)
+            # Update stats
+            self.percpu_percent = percpu_percent
         return self.percpu_percent
 
 
